pygeodesy.latlonBase

Package pygeodesy :: Module latlonBase |
[frames] | no frames]

# Module latlonBase

(INTERNAL) Base class LatLonBase for all elliposiodal, spherical and N-vectorial `LatLon` classes.

See Also: (C) Chris Veness 2005-2024' latlong, -ellipsoidal and -vectors and Charles Karney's Rhumb and RhumbLine classes.

Version: 25.08.18

Classes
| LatLonBase (INTERNAL) Base class for ellipsoidal and spherical `satLon`s.

Functions
latlon2n_xyz(lat_ll, lon=None, **name) Convert lat-, longitude to `n-vector` (normal to the earth's surface) X, Y and Z components. |
philam2n_xyz(phi_ll, lam=None, **name) Convert lat-, longitude to `n-vector` (normal to the earth's surface) X, Y and Z components. |

Variables
| __all__ = `_ALL_LAZY.latlonBase`

Function Details

### latlon2n_xyz (lat_ll, lon=None, **name) |
Convert lat-, longitude to `n-vector` (normal to the earth's surface) X, Y and Z components. Arguments: `lat_ll` - Latitude (`degrees`) or a `LatLon` instance, LatLon2Tuple or other `LatLon*Tuple`. `lon` - Longitude (`degrees`), required if `lon_ll is degrees`, ignored otherwise. `name` - Optional `name=NN` (`str`). Returns: A Vector3Tuple`(x, y, z)`. See Also: Function philam2n_xyz. Note: These are `n-vector` x, y and z components, NOT geocentric x, y and z (ECEF) coordinates!

### philam2n_xyz (phi_ll, lam=None, **name) |
Convert lat-, longitude to `n-vector` (normal to the earth's surface) X, Y and Z components. Arguments: `phi_ll` - Latitude (`radians`) or a `LatLon` instance with `phi`, `lam` or `philam` attributes. `lam` - Longitude (`radians`), required if `phi_ll is radians`, ignored otherwise. `name` - Optional name (`str`). Returns: A Vector3Tuple`(x, y, z)`. See Also: Function latlon2n_xyz. Note: These are `n-vector` x, y and z components, NOT geocentric x, y and z (ECEF) coordinates!